@@ -1642,7 +1642,7 @@ static void setup_relay_server(struct relay_server *rs, ioa_engine_handle e, int
 			 &turn_params.no_multicast_peers, &turn_params.no_loopback_peers,
 			 &turn_params.ip_whitelist, &turn_params.ip_blacklist,
 			 send_socket_to_relay,
-			 &turn_params.secure_stun, turn_params.shatype, &turn_params.mobility,
+			 &turn_params.secure_stun, &turn_params.mobility,
 			 turn_params.server_relay,
 			 send_turn_session_info,
 			 send_https_socket,
